"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

/**
 * @param {{
 *   recentActionsToTrack?: number
 *   maxByteSize?: number
 * }} [options]
 * @returns
 */
const getRecentActionsBundle = ({
  recentActionsToTrack = 20,
  maxByteSize = 10000
}) => ({
  name: 'recentActions',
  init: store => {
    const isTooBig = items => JSON.stringify(items).length > maxByteSize;

    store.getRecentActions = () => {
      try {
        const copy = [...store.meta.recentActions]; // this is important so we can trim down really large action payloads

        while (isTooBig(copy)) {
          copy.shift();
        }

        return copy;
      } catch (e) {
        return 'error serializing recent actions';
      }
    };
  },
  getMiddleware: () => store => next => action => {
    // only log non-idle actions
    if (action.type !== 'APP_IDLE') {
      const recentActions = store.meta.recentActions || (store.meta.recentActions = []);
      recentActions.push(action);

      if (recentActions.length > recentActionsToTrack) {
        recentActions.shift();
      }
    }

    return next(action);
  }
});

var _default = getRecentActionsBundle;
exports.default = _default;